configuration

package
v0.0.0-...-a4f318f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2021 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckMandatoryFields

func CheckMandatoryFields(config structs.Config) error

CheckMandatoryFields uses reflection to see if there are mandatory fields with zero value

func Load

func Load(path string) (cfg structs.Config, err error)

Load reads a configuration file and returns its config instance

Types

This section is empty.

Directories

Path Synopsis

Jump to